==> trigger-plugin-5.1.3-sources.jar: com/xebialabs/deployit/plugin/trigger/TriggerValidator.java <==
package com.xebialabs.deployit.plugin.trigger;

import com.xebialabs.deployit.plugin.api.validation.Rule;
import com.xebialabs.deployit.plugin.api.validation.ValidationContext;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

@Retention(RetentionPolicy.RUNTIME)
@Rule(clazz = TriggerValidator.Validator.class, type = "trigger")
@Target(ElementType.TYPE)
public @interface TriggerValidator  {

    @SuppressWarnings("rawtypes")
    public static class Validator implements com.xebialabs.deployit.plugin.api.validation.Validator<Trigger> {

        @Override
        public void validate(Trigger trigger, ValidationContext context) {
            if (!isRequiredValuesFilled(trigger, context)) {
                return;
            }

            if (trigger instanceof StepTrigger) {
                StepTrigger stepTrigger = (StepTrigger) trigger;
                if (!stepTrigger.getFromState().isValidTransition(stepTrigger.getToState())) {
                    context.error("Not a valid step state transition. %s cannot transition to %s", stepTrigger.getFromState(), stepTrigger.getToState());
                }
            } else {
                TaskTrigger taskTrigger = (TaskTrigger) trigger;
                if (!taskTrigger.getFromState().isValidTransition(taskTrigger.getToState())) {
                    context.error("Not a valid task state transition. %s cannot transition to %s", taskTrigger.getFromState(), taskTrigger.getToState());
                }
            }
        }

        private boolean isRequiredValuesFilled(Trigger trigger, ValidationContext context) {
            boolean isRequiredValuesFilled = true;
            if (trigger.getFromState() == null) {
                context.error("FromState value is required");
                isRequiredValuesFilled = false;
            }

            if (trigger.getToState() == null) {
                context.error("ToState value is required");
                isRequiredValuesFilled = false;
            }
            return isRequiredValuesFilled;
        }
    }
}

==> trigger-plugin-23.3.10-sources.jar: com/xebialabs/deployit/plugin/trigger/TriggerValidator.java <==
package com.xebialabs.deployit.plugin.trigger;

import com.xebialabs.deployit.plugin.api.validation.Rule;
import com.xebialabs.deployit.plugin.api.validation.ValidationContext;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

@Retention(RetentionPolicy.RUNTIME)
@Rule(clazz = TriggerValidator.ValidatorInstance.class, type = "trigger")
@Target(ElementType.TYPE)
public @interface TriggerValidator  {

    @SuppressWarnings("rawtypes")
    class ValidatorInstance implements com.xebialabs.deployit.plugin.api.validation.Validator<Trigger> {

        @Override
        public void validate(Trigger trigger, ValidationContext context) {
            if (!isRequiredValuesFilled(trigger, context)) {
                return;
            }

            if (trigger instanceof StepTrigger) {
                StepTrigger stepTrigger = (StepTrigger) trigger;
                if (!stepTrigger.getFromState().isValidTransition(stepTrigger.getToState())) {
                    context.error("Not a valid step state transition. %s cannot transition to %s", stepTrigger.getFromState(), stepTrigger.getToState());
                }
            } else {
                TaskTrigger taskTrigger = (TaskTrigger) trigger;
                if (!taskTrigger.getFromState().isValidTransition(taskTrigger.getToState())) {
                    context.error("Not a valid task state transition. %s cannot transition to %s", taskTrigger.getFromState(), taskTrigger.getToState());
                }
            }
        }

        private boolean isRequiredValuesFilled(Trigger trigger, ValidationContext context) {
            boolean isRequiredValuesFilled = true;
            if (trigger.getFromState() == null) {
                context.error("FromState value is required");
                isRequiredValuesFilled = false;
            }

            if (trigger.getToState() == null) {
                context.error("ToState value is required");
                isRequiredValuesFilled = false;
            }
            return isRequiredValuesFilled;
        }
    }
}
